.. _baseclass:

Baseclass
---------

.. currentmodule:: chaospy

.. autosummary::
   :template: distribution.rst
   :toctree: ../../api

   Distribution

.. autosummary::
   :toctree: ../../api

   Distribution.pdf
   Distribution.cdf
   Distribution.ppf
   Distribution.fwd
   Distribution.inv
   Distribution.sample
   Distribution.mom
   Distribution.ttr

   Distribution.interpret_as_integer
   Distribution.stochastic_dependent
   Distribution.lower
   Distribution.upper
